==> rabbit-task-3.0.10.tgz: package/src/lib/listener.js <==
/**
 * Created by asafdavid on 08/12/2015.
 */
import { EventEmitter } from 'events';
import _ from 'lodash';
import Chance from 'chance';
import logger from './logger';
import PostgresPuller from './puller/postgresPuller';

const chance = new Chance();
const DEFAULT_CONSUMER_QOS = 10;

export default class Listener extends EventEmitter {
  constructor(channel, queue, consumerTag, qosLimit, pullOptions) {
    super();
    this.channel = channel;
    this.queue = queue;
    this.consumerTag = consumerTag;
    this.qosLimit = qosLimit || DEFAULT_CONSUMER_QOS;
    this.puller = _.isEmpty(pullOptions) ? undefined : new PostgresPuller(pullOptions);
  }

  /**
   * Start consuming messages
   */
  start() {
    logger.instance.log('[AMQP] Listener starts');
    let options = { noAck: false };
    const hasConsumerTag = !!this.consumerTag;
    options = hasConsumerTag ?
      _.extend(options, { consumerTag: `${this.consumerTag}-${chance.hash({ length: 5 })}` }) :
      options;

    if (!this.puller) {
      logger.instance.info(`[AMQP] Listener starts in *Push* mode. QOS: ${this.qosLimit}`);

      this.channel.prefetch(this.qosLimit);

      return this.channel.consume(
        this.queue,
        msg => this.processMsg(msg),
        options,
      ).then((fields) => {
        this.consumerTag = fields.consumerTag;
      });
    }

    logger.instance.info('[AMQP] Listener starts in *Pull* mode');
    return this.puller.start(this.channel, this.queue, msg => this.processMsg(msg));
  }

  /**
   * Processes the next msg
   * @param msg
   */
  processMsg(msg) {
    if (msg) {
      logger.instance.debug('[AMQP] received a msg',
        { consumerTag: msg.fields.consumerTag || 'Pull mode' });
      this.emit('msg', msg);
    }
  }

  /**
   * Stops consuming messages
   */
  stop() {
    if (this.consumerTag) {
      logger.instance.info('[AMQP] Listener stops listening to consumer tag',
        { consumerTag: this.consumerTag });
      return this.channel.cancel(this.consumerTag);
    } else if (this.puller) {
      return this.puller.stop();
    }

    return Promise.resolve();
  }
}

==> rabbit-task-3.0.18.tgz: package/src/lib/listener.js <==
/**
 * Created by asafdavid on 08/12/2015.
 */
import { EventEmitter } from 'events';
import _ from 'lodash';
import Chance from 'chance';
import logger from './logger';
import PostgresPuller from './puller/postgresPuller';

const chance = new Chance();
const DEFAULT_CONSUMER_QOS = 10;

export default class Listener extends EventEmitter {
  constructor(channel, queue, consumerTag, qosLimit, pullOptions) {
    super();
    this.channel = channel;
    this.queue = queue;
    this.consumerTag = consumerTag;
    this.qosLimit = qosLimit || DEFAULT_CONSUMER_QOS;
    this.puller = _.isEmpty(pullOptions) ? undefined : new PostgresPuller(pullOptions);
  }

  /**
   * Start consuming messages
   */
  start() {
    logger.instance.log('[AMQP] Listener starts');
    let options = { noAck: false };
    const hasConsumerTag = !!this.consumerTag;
    options = hasConsumerTag ?
      _.extend(options, { consumerTag: `${this.consumerTag}-${chance.hash({ length: 5 })}` }) :
      options;

    if (!this.puller) {
      logger.instance.info(`[AMQP] Listener starts in *Push* mode. QOS: ${this.qosLimit}`);

      this.channel.prefetch(this.qosLimit);

      return this.channel.consume(
        this.queue,
        msg => this.processMsg(msg),
        options,
      ).then((fields) => {
        this.consumerTag = fields.consumerTag;
      });
    }

    logger.instance.info('[AMQP] Listener starts in *Pull* mode');
    return this.puller.start(this.channel, this.queue, msg => this.processMsg(msg));
  }

  /**
   * Processes the next msg
   * @param msg
   */
  processMsg(msg) {
    if (msg) this.emit('msg', msg);
  }

  /**
   * Stops consuming messages
   */
  stop() {
    if (this.consumerTag) {
      logger.instance.info('[AMQP] Listener stops listening to consumer tag',
        { consumerTag: this.consumerTag });
      return this.channel.cancel(this.consumerTag);
    } else if (this.puller) {
      return this.puller.stop();
    }

    return Promise.resolve();
  }
}
